@@ -8,7 +8,7 @@ use Carp;
 use vars qw( $SOCKET_CLASS @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $VERSION $SOCKS_ERROR $SOCKS5_RESOLVE $SOCKS4_RESOLVE $SOCKS_DEBUG %CODES );
 require Exporter;
 
-$VERSION = '0.70';
+$VERSION = '0.71';
 
 use constant {
 	SOCKS_WANT_READ  => 20,
@@ -176,6 +176,7 @@ sub start_SOCKS {
 
 	${*$sock}->{SOCKS} = { RequireAuth => 0 };
 
+	$SOCKS_ERROR->set();
 	return $sock->command(%arg) ? $sock : undef;
 }
 
@@ -361,6 +362,7 @@ sub connect {
 
 	if (($! == EINPROGRESS || $! == EWOULDBLOCK) && 
 	    (${*$self}->{SOCKS}->{TCP} || $self)->blocking == 0) {
+		${*$self}->{SOCKS}->{_in_progress} = 1;
 		$SOCKS_ERROR->set(SOCKS_WANT_WRITE, 'Socks want write');
 	}
 	elsif (!$ok) {
@@ -409,11 +411,7 @@ sub _connect {
 		];
 	}
 
-	if ($SOCKS_ERROR == undef) {    # socket connection estabilished
-		defined($self->_run_queue())
-		  or return;
-	}
-	else {
+	if (delete ${*$self}->{SOCKS}->{_in_progress}) { # socket connection not estabilished yet
 		if ($self->isa('IO::Socket::IP')) {
 			# IO::Socket::IP requires multiple connect calls
 			# when performing non-blocking multi-homed connect
@@ -425,6 +423,10 @@ sub _connect {
 			return; # connect() return value
 		}
 	}
+	else {
+		defined($self->_run_queue())
+			or return;
+	}
 
 	return $self;
 }
