@@ -7,6 +7,10 @@ sub make_socks_server {
 	my ($version, $login, $password, %delay) = @_;
 	
 	my $serv = IO::Socket::Socks->new(Listen => 3, SocksVersion => $version, RequireAuth => ($login && $password), UserAuth => sub {
+		$login = ''    unless defined $login;
+		$password = '' unless defined $password;
+		$_[0] = '' unless defined $_[0];
+		$_[1] = '' unless defined $_[1];
 		return $_[0] eq $login && $_[1] eq $password;
 	}) or die $@;
 	
@@ -82,7 +86,7 @@ sub make_socks_server {
 		}
 	}
 	
-	return ($child, $serv->sockhost eq "0.0.0.0" ? "127.0.0.1" : $serv->sockhost, $serv->sockport);
+	return ($child, fix_addr($serv->sockhost), $serv->sockport);
 }
 
 sub make_http_server {
@@ -141,7 +145,13 @@ sub make_http_server {
 		exit;
 	}
 	
-	return ($child, $serv->sockhost eq "0.0.0.0" ? "127.0.0.1" : $serv->sockhost, $serv->sockport);
+	return ($child, fix_addr($serv->sockhost), $serv->sockport);
+}
+
+sub fix_addr {
+	return '127.0.0.1' if $_[0] eq '0.0.0.0';
+	return '0:0:0:0:0:0:0:1' if $_[0] eq '::';
+	return $_[0];
 }
 
 1;
